#pragma once

extern "C" {
void init_version();
void init_compat();
void init_server();
void init_multiplayer();
void init_benchmark();
void init_sound();
void init_input();
void init_camera();
void init_atlas();
void init_title_screen();
void init_skin();
void init_fps();
void init_touch();
void init_textures();
void init_creative();
void init_game_mode();
void init_misc();
void init_death();
void init_options();
void init_chat();
void init_bucket();
void init_cake();
void init_override();
void init_screenshot();
void init_f3();
void init_multidraw();
void init_classic_ui();
void init_api();
void init_shading();
}
